@@ -20,7 +20,7 @@ class Battery(Buffer):
     efficiency eta is modelled by fitting a polynomial model to data measured
     by TU Munich.
 
-    You have to provide the two dictionaries *params* and *init_vals*.
+    You have to provide the two dictionaries *params* and *inits*.
     *params* provides the configuration parameters for the battery model and
     might look like this::
 
@@ -41,7 +41,7 @@ class Battery(Buffer):
     quadratic polynomial function, which is used to model power dependency of
     efficiency.
 
-    The dict *init_vals* provides initial values for state variables. The
+    The dict *inits* provides initial values for state variables. The
     battery model has only one state variable that must be specified when the
     model is initialized. It is *soc_percent*, which indicates the initial
     state of charge in percent of battery capacity. The model has two more
