@@ -16,13 +16,13 @@ from .state import CHPLPGSystemState
 class CHPLPGSystem(Generator):
     """CHP system with CHP and household"""
 
-    def __init__(self, params, init_vals):
+    def __init__(self, params, inits):
 
         # First, create the chp
         params["chp"]["sign_convention"] = params.get(
             "sign_convention", "passive"
         )
-        self.chp = CHPLPG(params["chp"], init_vals["chp"])
+        self.chp = CHPLPG(params["chp"], inits["chp"])
 
         # Get the thermal capabilities of the chp
         p_th_min_kw = (
@@ -34,11 +34,11 @@ class CHPLPGSystem(Generator):
 
         # Second, create an appropriate household
         self.heatdemand = create_heatdemand(
-            params["household"], init_vals["household"]
+            params["household"], inits["household"]
         )
 
         self.config = CHPLPGSystemConfig(params)
-        self.state = CHPLPGSystemState(init_vals)
+        self.state = CHPLPGSystemState(inits)
         self.inputs = CHPLPGSystemInputs()
 
     def step(self):
