@@ -8,6 +8,7 @@ from datetime import datetime, timedelta, timezone
 from typing import Any, Dict, Union
 
 from midas.util.logging import set_and_init_logger
+from midas.util.runtime_config import RuntimeConfig
 import mosaik_api
 import numpy as np
 import pandas as pd
@@ -37,6 +38,10 @@ class FlexibilitySimulator(mosaik_api.Simulator):
         self.planning_horizon = None
         self.num_schedules = 0
 
+        self._key_value_logs: bool = RuntimeConfig().misc.get(
+            "key_value_logs", False
+        )
+
     def init(self, sid, **sim_params):
         """Called exactly ones after the simulator has been started.
 
@@ -187,6 +192,11 @@ class FlexibilitySimulator(mosaik_api.Simulator):
         for eid, attrs in outputs.items():
             data[eid] = dict()
             # model = eid.split("-")[0]
+            log_msg = {
+                "id": f"{self.sid}_{eid}",
+                "name": eid,
+                "type": "modelname",
+            }
             for attr in attrs:
 
                 if attr == "flexibilities":
@@ -201,6 +211,7 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                         ]
                         .to_json()
                     )
+                    log_msg[attr] = value
                 elif attr == "target":
                     value = self.models[eid].schedule._data.loc[
                         self.now_dt - timedelta(seconds=self.step_size)
@@ -224,8 +235,13 @@ class FlexibilitySimulator(mosaik_api.Simulator):
                     if attr in ("p_mw", "p_th_mw", "q_mvar"):
                         value *= 1e-3
 
+                    log_msg[attr] = value
+
                 data.setdefault(eid, dict())[attr] = value
 
+            if self._key_value_logs:
+                LOG.info(log_msg)
+
         LOG.debug("Gathered outputs: %s.", data)
         return data
 
