@@ -25,11 +25,21 @@ class PysimmodsModule(UpgradeModule):
             module_name="der",
             default_scope_name="midasmv",
             default_sim_config_name="Pysimmods",
-            default_import_str="pysimmods.mosaik:PysimmodsSimulator",
-            default_cmd_str="TODO",
+            default_import_str=(
+                "pysimmods.mosaik.pysim_mosaik:PysimmodsSimulator"
+            ),
+            default_cmd_str=(
+                "%(python)s -m pysimmods.mosaik.pysim_mosaik %(addr)s"
+            ),
             log=LOG,
         )
 
+        self.flex_import_str = (
+            "pysimmods.mosaik.flex_mosaik:FlexibilitySimulator"
+        )
+        self.flex_cmd_str = (
+            "%(python)s -m pysimmods.mosaik.flex_mosaik %(addr)s"
+        )
         self.models = {
             "PV": (
                 "Photovoltaic",
@@ -91,10 +101,15 @@ class PysimmodsModule(UpgradeModule):
         module_params.setdefault("unit", "mw")
         module_params.setdefault("use_decimal_percent", False)
         module_params.setdefault("priorize_setpoint", False)
+        module_params.setdefault(
+            "provide_forecasts", module_params["provide_flexibilities"]
+        )
+        module_params.setdefault(
+            "enable_schedules", module_params["provide_forecasts"]
+        )
 
     def check_sim_params(self, module_params, **kwargs):
         """Check the params for a certain simulator instance."""
-
         self.sim_params.setdefault("grid_name", self.scope_name)
         self.sim_params.setdefault("start_date", module_params["start_date"])
         self.sim_params.setdefault("cos_phi", module_params["cos_phi"])
@@ -133,6 +148,16 @@ class PysimmodsModule(UpgradeModule):
         self.sim_params.setdefault(
             "priorize_setpoint", module_params["priorize_setpoint"]
         )
+        self.sim_params.setdefault(
+            "provide_forecasts",
+            self.sim_params["provide_flexibilities"]
+            or module_params["provide_forecasts"],
+        )
+        self.sim_params.setdefault(
+            "enable_schedules",
+            self.sim_params["provide_forecasts"]
+            or module_params["enable_schedules"],
+        )
         # self.sim_params.setdefault("mapping", dict())
         # self.sim_params.setdefault("weather_provider_mapping", dict())
         # self.sim_params.setdefault("weather_forecast_mapping", dict())
@@ -143,6 +168,16 @@ class PysimmodsModule(UpgradeModule):
         else:
             self.sim_params.setdefault("seed", self.scenario.create_seed())
 
+        if (
+            self.sim_params["enable_schedules"]
+            or self.sim_params["provide_forecasts"]
+            or self.sim_params["provide_flexibilities"]
+        ):
+            if self.sim_params["cmd"] == "python":
+                self.sim_params["import_str"] = self.flex_import_str
+            elif self.sim_params["cmd"] == "cmd":
+                self.sim_params["import_str"] = self.flex_cmd_str
+
     def start_models(self):
         """Start all models defined in the mapping of a certain simulator."""
         mapping_key = "peak_mapping"
