@@ -1,4 +1,5 @@
 from datetime import datetime
+from typing import Optional
 
 import numpy as np
 from pysimmods.model.model import Model
@@ -19,7 +20,8 @@ class ScheduleModel:
         model: Model,
         unit: str = "kw",
         priorize_setpoint: bool = False,
-    ) -> None:
+        use_absolute_schedule: bool = False,
+    ):
 
         self._model = model
         self._priorize_setpoint = priorize_setpoint
@@ -37,10 +39,15 @@ class ScheduleModel:
             self._pname = "p_kw"
             self._qname = "q_kvar"
 
-        self.schedule: Schedule = None
-        self._step_size: float = None
-        self._now_dt: datetime = None
-        self._percent_factor: float = None
+        self.schedule: Optional[Schedule] = None
+        self._step_size: Optional[float] = None
+        self._now_dt: Optional[datetime] = None
+        self._percent_factor: float
+
+        if self._model.config.use_decimal_percent:
+            self._percent_factor = 0.01
+        else:
+            self._percent_factor = 1.0
 
     def update_schedule(self, schedule):
         if self.schedule is None:
